@@ -14,10 +14,10 @@ DOCUMENTATION = '''
 module: git_acp
 author:
     - "Federico Olivieri (@Federico87)"
-short_description: Perform git add, commit and push operations.
+short_description: Perform git add, commit and push operations. Set git config user name and email.
 description:
-    - Manage C(git add), C(git commit) and C(git push) on a local
-      or remote git repositroy.
+    - Manage C(git add), C(git commit) C(git push), C(git config) user name and email on a local
+      or remote git repository.
 options:
     path:
         description:
@@ -35,7 +35,6 @@ options:
               File globs not accepted, such as C(./*) or C(*).
         type: list
         elements: str
-        required: true
         default: ["."]
     user:
         description:
@@ -72,11 +71,11 @@ options:
         type: str
         default: origin
     user_name:
-        decription:
+        description:
             - Explicit git local user name. Nice to have for remote operations.
         type: str
     user_email:
-        decription:
+        description:
             - Explicit git local email address. Nice to have for remote operations.
         type: str
 
@@ -133,16 +132,27 @@ from ansible.module_utils.basic import AnsibleModule
 
 
 def user_conifg(module):
+    """
+    Config git local user.name and user.email.
 
+    args:
+        * module:
+            type: dict()
+            descrition: Ansible basic module utilities and module arguments.
+    return:
+        * result:
+            type: dict()
+            desription: update change status.
+    """
     result = dict()
-    user_name = module.params.get('user_name') 
+    user_name = module.params.get('user_name')
     user_email = module.params.get('user_email')
     path = module.params.get('path')
 
     get_name_cmd = [
         'git',
-        'config', 
-        '--local', 
+        'config',
+        '--local',
         'user.name',
     ]
 
@@ -151,8 +161,8 @@ def user_conifg(module):
 
         name_cmd = [
             'git',
-            'config', 
-            '--local', 
+            'config',
+            '--local',
             'user.name',
             user_name
         ]
@@ -165,8 +175,8 @@ def user_conifg(module):
 
     get_email_cmd = [
         'git',
-        'config', 
-        '--local', 
+        'config',
+        '--local',
         'user.email',
     ]
 
@@ -175,8 +185,8 @@ def user_conifg(module):
 
         email_cmd = [
             'git',
-            'config', 
-            '--local', 
+            'config',
+            '--local',
             'user.email',
             user_email
         ]
@@ -227,7 +237,7 @@ def git_status(module):
             type: dict()
             descrition: Ansible basic module utilities and module arguments.
     return:
-        * data: 
+        * data:
             type: set()
             description: list of files changed in repo.
     """
@@ -260,7 +270,7 @@ def git_commit(module):
             type: dict()
             descrition: Ansible basic module utilities and module arguments.
     return:
-        * result: 
+        * result:
             type: dict()
             desription: returned output from git commit command and changed status
     """
@@ -300,7 +310,7 @@ def git_push(module):
             type: dict()
             descrition: Ansible basic module utilities and module arguments.
     return:
-        * result: 
+        * result:
             type: dict()
             desription: returned output from git push command and updated changed status.
     """
@@ -327,14 +337,14 @@ def git_push(module):
             '--all',
             origin,
         ]
-        
+
         path = module.params.get('path')
 
         rc, _output, _error = module.run_command(get_url_cmd, cwd=path)
 
         if rc == 0:
             return
-        
+
         if rc == 128:
             if mode == 'https':
                 if url.startswith('https://'):
@@ -367,7 +377,6 @@ def git_push(module):
             if rc == 0:
                 return
 
-
     def git_push_cmd(path, cmd_push):
         """
         Set URL and remote if required. Push changes to remote repo.
@@ -380,7 +389,7 @@ def git_push(module):
                 type: list()
                 descrition: list of commands to perform git push operation.
         return:
-            * result: 
+            * result:
                 type: dict()
                 desription: returned output from git push command and updated changed status.
         """
@@ -420,7 +429,15 @@ def git_push(module):
 
 
 def main():
+    """
+    Code entrypoint.
 
+    args: none
+    return:
+        * result:
+            type: dict()
+            desription: returned output from git commands and updated changed status.
+    """
     argument_spec = dict(
         path=dict(required=True, type="path"),
         comment=dict(required=True),
@@ -457,22 +474,24 @@ def main():
     user_email = module.params.get('user_email')
 
     if mode == 'local':
-        if url.startswith(('https://', 'git@', 'ssh://git@')):
-            module.fail_json(msg='SSH or HTTPS mode selected but repo is LOCAL')
+        if url.startswith(('https://', 'git', 'ssh://git')):
+            module.fail_json(msg='SSH or HTTPS mode selected but repo is "local')
 
         if push_option:
             module.fail_json(msg='"--push-option" not supported with mode "local"')
 
     if mode == 'https':
         if not url.startswith('https://'):
-            module.fail_json(msg='HTTPS mode selected but url ('+url+') is not HTTPS')
+            module.fail_json(msg='HTTPS mode selected but url (' + url + ') not starting with "https"')
 
     if mode == 'ssh':
-        if not url.startswith(('git@', 'ssh://git@')):
-            module.fail_json(msg='SSH mode selected but url ('+url+') not starting with git@ or ssh://git@')
+        if not url.startswith(('git', 'ssh://git')):
+            module.fail_json(
+                msg='SSH mode selected but url (' + url + ') not starting with "git" or "ssh://git"'
+            )
 
         if url.startswith('ssh://git@github.com'):
-            module.fail_json(msg='GitHub does not support "ssh://" URL. Please remove it from url: '+url+'')
+            module.fail_json(msg='GitHub does not support "ssh://" URL. Please remove it from url')
 
     result = dict(changed=False)
 
